<?php

namespace IPS\tabbedforumsindex;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

class _Tab extends \IPS\Node\Model implements \IPS\Node\Permissions
{
	protected static $multitons;
	public static $databaseTable = 'tabbedforumsindex_tabs';
	public static $databasePrefix = 'tab_';
	public static $databaseColumnOrder = 'position';
	public static $modalForms = TRUE;
	public static $nodeTitle = 'menu__tabbedforumsindex_tabs_tabs';

	protected static $restrictions = array(
		'app'		=> 'tabbedforumsindex',
		'module'	=> 'tabs',
		'prefix' 	=> 'tabs_'
	);

	public static $titleLangPrefix = 'tabbedforumsindex_tab_';
	public static $modPerm = 'tabbedforumsindex_tab';
	public static $permApp = 'tabbedforumsindex';
	public static $permType = 'tab';
	public static $permissionMap = array( 'view' => 'view' );
    public static $permissionLangPrefix = 'tabbedforumsindex_tabs_';
	public static $databaseColumnEnabledDisabled = 'active';

	protected function get__description()
	{
		switch( $this->type )
		{
			case 'all':
				$text = \IPS\Member::loggedIn()->language()->addToStack( 'menu_manager_extension' ) . ': ' . \IPS\Member::loggedIn()->language()->addToStack( 'tabbedforumsindex_tab_all' );
			break;
			case 'categories':
				$text = \IPS\Member::loggedIn()->language()->addToStack( 'menu_manager_extension' ) . ': ' . \IPS\Member::loggedIn()->language()->addToStack( 'tabbedforumsindex_tab_categories' );
			break;
			case 'forums':
				$text = \IPS\Member::loggedIn()->language()->addToStack( 'menu_manager_extension' ) . ': ' . \IPS\Member::loggedIn()->language()->addToStack( 'tabbedforumsindex_tab_forums' );
			break;
			case 'clubs':
				$text = \IPS\Member::loggedIn()->language()->addToStack( 'menu_manager_extension' ) . ': ' . \IPS\Member::loggedIn()->language()->addToStack( 'tabbedforumsindex_tab_clubs' );
			break;
		}

		return $text;
	}

	public function form( &$form )
	{
		$form->add( new \IPS\Helpers\Form\Translatable( 'tab_title', NULL, TRUE, array( 'app' => 'tabbedforumsindex', 'key' => ( $this->id ? "tabbedforumsindex_tab_{$this->id}" : NULL ) ) ) );		

		$options = array(
			'all' 			=> 'tabbedforumsindex_tab_all',
			'categories' 	=> 'tabbedforumsindex_tab_categories',
			'forums'		=> 'tabbedforumsindex_tab_forums',
			'clubs' 		=> 'tabbedforumsindex_tab_clubs'
		);
		$toggles = array(
			'categories'	=> array( 'tab_type_cats' ),
			'forums'		=> array( 'tab_type_forums' ),
			'clubs'			=> array( 'tab_type_clubs' )
		);
		$form->add( new \IPS\Helpers\Form\Radio( 'tab_type', $this->id ? $this->type : 'all', FALSE, array( 'options' => $options, 'toggles' => $toggles	) ) );

		$form->add( new \IPS\Helpers\Form\Node( 'tab_type_cats', $this->id ? explode( ',', $this->source_ids ) : array(), TRUE, array( 'class' => 'IPS\forums\Forum', 'autoPopulate' => FALSE, 'multiple' => TRUE, 'permissionCheck' => function ( $forum )
		{
			return $forum->parent_id == -1 AND $forum->club_id == NULL;
		} ), NULL, NULL, NULL, 'tab_type_cats' ) );

		$form->add( new \IPS\Helpers\Form\Node( 'tab_type_forums', $this->id ? explode( ',', $this->source_ids ) : array(), TRUE, array( 'class' => 'IPS\forums\Forum', 'multiple' => TRUE, 'permissionCheck' => function ( $forum )
		{
			return $forum->sub_can_post AND !$forum->redirect_url AND $forum->club_id == NULL;
		} ), NULL, NULL, NULL, 'tab_type_forums' ) );

		$form->add( new \IPS\Helpers\Form\Node( 'tab_type_clubs', $this->id ? explode( ',', $this->source_ids ) : array(), TRUE, array( 'class' => 'IPS\forums\Forum', 'multiple' => TRUE, 'autoPopulate' => FALSE, 'clubs' => TRUE, 'permissionCheck' => function ( $forum )
		{
			return $forum->sub_can_post AND !$forum->redirect_url AND $forum->club_id != NULL;
		} ), NULL, NULL, NULL, 'tab_type_clubs' ) );

		$styles = array(
			'table' => 'tabbedforumsindex_style_table',
			'grid' 	=> 'tabbedforumsindex_style_grid'
		);
		$form->add( new \IPS\Helpers\Form\Radio( 'tab_style', $this->id ? $this->style : 'table', FALSE, array( 'options' => $styles ) ) );

		$form->add( new \IPS\Helpers\Form\Text( 'tab_icon', $this->id ? $this->icon : NULL ) );
		$form->add( new \IPS\Helpers\Form\YesNo( 'tab_active', $this->id ? $this->active : TRUE ) );
		$form->hiddenValues['tab_source_ids'] = '';
	}

	public function formatFormValues( $values )
	{
		if( !$this->id )
		{
			$this->save();			
		}

		foreach( array( 'tab_title' => "tabbedforumsindex_tab_{$this->id}" ) as $fieldKey => $langKey )
		{
			if( array_key_exists( $fieldKey, $values ) )
			{
				\IPS\Lang::saveCustom( 'tabbedforumsindex', $langKey, $values[ $fieldKey ] );
				unset( $values[ $fieldKey ] );
			}
		}

		$ids = array();

		if( $values['tab_type'] == 'all' )
		{
			$values['tab_source_ids'] = '';
		}
		else
		{
			switch( $values['tab_type'] )
			{
				case 'categories':
					$field = 'tab_type_cats';
				break;
				case 'forums':
					$field = 'tab_type_forums';
				break;
				case 'clubs':
					$field = 'tab_type_clubs';
				break;
			}

			foreach( $values[ $field ] as $idx => $cat )
			{
				$ids[] = $idx;
			}
			$values['tab_source_ids'] = implode( ',', $ids );
		}

		unset( $values['tab_type_cats'] );
		unset( $values['tab_type_forums'] );	
		unset( $values['tab_type_clubs'] );

		return $values;
	}
}